function [R,T]=factRT(obj)
% FactRT returns the reflection and transmission probabilities 
%   of a physical object which interacts with a step of potential energy.
%
%   [R,T]=FactRT(obj)
%       >> obj  = Step object
%       << R    = Probability of reflection
%       << T    = Probability of transmission
%
%% Verifications

if (isa(obj,'step')==0),error('Bad object type!');end
if (obj.ke==0),error('Singular case k=0!');end

%% Step matrix

mat=matrix(obj);
%
%% Computing of factors R and T

if (isreal(obj.ks)==1)
    T=1/(abs(mat(2,2)))^2;
    R=(abs(-mat(2,1)/mat(2,2)))^2;
end
%
if (isreal(obj.ks)==0)
     T=0;
     R=1;
end
%
return;