function mat=translation(obj1,obj2)
% TRANSLATION computes the matrix of propagation from a step to another.
%   This matrix is characteristic of a region (length L) of uniform potential 
%   energy.
%
%   mat=translation(obj1,obj2)
%       >> obj1 = Step object 1
%       >> obj2 = Step object 2
%       << mat  = matrix of propagation from step 1 to step 2
%
%   Olivier Pujol (2006)
%
%% Verifications

if ( (isa(obj1,'step')==0) || (isa(obj2,'step')==0) ),error('Bad object type!');end
if ( (obj2.ke==0)||(obj1.ks==0) ),error('Singular case k=0!');end

%% Matrix computing

mat=eye(2);
L=obj2.x-obj1.x;
k0=obj1.ks;
mat(1,1)=exp(1i*k0*L);
mat(2,2)=exp(-1i*k0*L);
%
return;