function [sys,E]=Epot(M,xt,Ep,m,E)
% Epot permits to construct the system {potential energy - physical object}.
%
%   [sys,E]=Epot(M,xt,Ep,m,E)
%       >> M    = Step names
%       >> xt   = Step positions on Ox axis
%       >> Ep   = Potential energy values 
%       >> m    = Physical object mass (with respect to electron mass)
%       >> E    = Physical object energy values
%       << sys  = System. Number of systems = number of energy values
%       << E    = E-values kept (E=Ep is excluded to avoid the singularity k=0) 
%
%   Olivier Pujol (2010)
%
%% Verifications

if (m<=0),error('Mass must be positive !');end
if (length(Ep)~=length(xt)+1),error('Incorrect number of Ep-values!');end

% It must be verified that none value of E equal a value of Ep
for i=1:length(Ep)
    Ind=(abs(E-Ep(i))<eps); % Finding E-values such that E=Ep
    E=E(Ind~=1);            % Previous values are not kept
end
clear i Ind

%% Initialization

sys=cell(size(E));
k=cell(size(E));
step=cell(size(xt));

%% Construction of the system {Potential energy-physical object}
for n=1:length(E)
    k{n}=WaveVect(E(n),m,Ep);

    for p=1:length(xt)
        step{p}=step(M{p},xt(p),Ep(p),Ep(p+1),k{n}(p),k{n}(p+1));
    end
    sys{n}=System(step{1:end});
end

return;