function graphE(sys,E,param)
% graphE plots the considered potential energy and a parameter chosen by user 
% (the most interesting is the transmission probability T) versus energy values.  
%
%   graphE(sys,E,param)
%       >>  sys 	= System
%       >>  E 		= Physical object energy values 
%       >>  param	= Parameter considered
%
% Olivier Pujol (2010)
%
%%
if (nargin~=3);error('Bad number of input arguments!');end
if (isa(sys,'cell')==0),error('First argument must be of type ''cell'' !');end
%
L=get(sys{1}{length(sys{1})},'Position')-get(sys{1}{2},'Position');
xmin=get(sys{1}{2},'Position')-0.5*L;
xmax=get(sys{1}{length(sys{1})},'Position')+0.5*L;
clear L
%
pos=nan(1,length(sys{1})-1);    % Initialization
Ep=nan(1,length(sys{1})-1);     % Initialization
%
for i=2:length(sys{1})
    if (isa(sys{1}{i},'step')==0),error('Bad type argument!');end
    pos(i-1)=get(sys{1}{i},'Position');
    Ep(i-1)=get(sys{1}{i},'OutputPotentialEnergy');
end
%
pos=[xmin pos xmax];
Ep_e=sys{1}{1}(1);
Ep_s=sys{1}{1}(2);
Ep=[Ep_e Ep Ep_s];
%
figure;
subplot(1,2,1)
hs=stairs(pos,Ep);
set(hs,'LineWidth',2,'Color','b');
axis([xmin xmax min(Ep) max(E)]);
set(gca,'xminortick','on','yminortick','on');
grid on;
box on
xlabel('{\itx} (nm)');
title('{Potential energy (eV)}');

subplot(1,2,2);
plot(param,E);
set(gca,'xminortick','on','yminortick','on');
grid on;
box on
axis tight
labelx=input('Notation of the plotted parameter versus E: ');
xlabel(labelx);
ylabel('{\itE} (eV)');
%
return;